# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EdgeCert(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ca_certificate': 'str',
        'certificate': 'str',
        'client_certificate': 'str',
        'client_private_key': 'str',
        'edge_certificate': 'str',
        'edge_id': 'str',
        'edge_private_key': 'str',
        'id': 'str',
        'locked': 'bool',
        'private_key': 'str'
    }

    attribute_map = {
        'ca_certificate': 'CACertificate',
        'certificate': 'certificate',
        'client_certificate': 'clientCertificate',
        'client_private_key': 'clientPrivateKey',
        'edge_certificate': 'edgeCertificate',
        'edge_id': 'edgeId',
        'edge_private_key': 'edgePrivateKey',
        'id': 'id',
        'locked': 'locked',
        'private_key': 'privateKey'
    }

    def __init__(self, ca_certificate=None, certificate=None, client_certificate=None, client_private_key=None, edge_certificate=None, edge_id=None, edge_private_key=None, id=None, locked=None, private_key=None):  # noqa: E501
        """EdgeCert - a model defined in Swagger"""  # noqa: E501
        self._ca_certificate = None
        self._certificate = None
        self._client_certificate = None
        self._client_private_key = None
        self._edge_certificate = None
        self._edge_id = None
        self._edge_private_key = None
        self._id = None
        self._locked = None
        self._private_key = None
        self.discriminator = None
        self.ca_certificate = ca_certificate
        self.certificate = certificate
        self.client_certificate = client_certificate
        self.client_private_key = client_private_key
        self.edge_certificate = edge_certificate
        self.edge_id = edge_id
        self.edge_private_key = edge_private_key
        if id is not None:
            self.id = id
        if locked is not None:
            self.locked = locked
        self.private_key = private_key

    @property
    def ca_certificate(self):
        """Gets the ca_certificate of this EdgeCert.  # noqa: E501

        Root CA certificate for the tenant.  # noqa: E501

        :return: The ca_certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._ca_certificate

    @ca_certificate.setter
    def ca_certificate(self, ca_certificate):
        """Sets the ca_certificate of this EdgeCert.

        Root CA certificate for the tenant.  # noqa: E501

        :param ca_certificate: The ca_certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if ca_certificate is None:
            raise ValueError("Invalid value for `ca_certificate`, must not be `None`")  # noqa: E501

        self._ca_certificate = ca_certificate

    @property
    def certificate(self):
        """Gets the certificate of this EdgeCert.  # noqa: E501

        Certificate for the edge using old/fixed root CA.  # noqa: E501

        :return: The certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this EdgeCert.

        Certificate for the edge using old/fixed root CA.  # noqa: E501

        :param certificate: The certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if certificate is None:
            raise ValueError("Invalid value for `certificate`, must not be `None`")  # noqa: E501

        self._certificate = certificate

    @property
    def client_certificate(self):
        """Gets the client_certificate of this EdgeCert.  # noqa: E501

        Certificate for mqtt client on the edge  # noqa: E501

        :return: The client_certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._client_certificate

    @client_certificate.setter
    def client_certificate(self, client_certificate):
        """Sets the client_certificate of this EdgeCert.

        Certificate for mqtt client on the edge  # noqa: E501

        :param client_certificate: The client_certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if client_certificate is None:
            raise ValueError("Invalid value for `client_certificate`, must not be `None`")  # noqa: E501

        self._client_certificate = client_certificate

    @property
    def client_private_key(self):
        """Gets the client_private_key of this EdgeCert.  # noqa: E501

        Encrypted private key corresponding to the client certificate.  # noqa: E501

        :return: The client_private_key of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._client_private_key

    @client_private_key.setter
    def client_private_key(self, client_private_key):
        """Sets the client_private_key of this EdgeCert.

        Encrypted private key corresponding to the client certificate.  # noqa: E501

        :param client_private_key: The client_private_key of this EdgeCert.  # noqa: E501
        :type: str
        """
        if client_private_key is None:
            raise ValueError("Invalid value for `client_private_key`, must not be `None`")  # noqa: E501

        self._client_private_key = client_private_key

    @property
    def edge_certificate(self):
        """Gets the edge_certificate of this EdgeCert.  # noqa: E501

        Certificate for the edge using per-tenant root CA.  # noqa: E501

        :return: The edge_certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._edge_certificate

    @edge_certificate.setter
    def edge_certificate(self, edge_certificate):
        """Sets the edge_certificate of this EdgeCert.

        Certificate for the edge using per-tenant root CA.  # noqa: E501

        :param edge_certificate: The edge_certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if edge_certificate is None:
            raise ValueError("Invalid value for `edge_certificate`, must not be `None`")  # noqa: E501

        self._edge_certificate = edge_certificate

    @property
    def edge_id(self):
        """Gets the edge_id of this EdgeCert.  # noqa: E501

        ID of the edge this entity belongs to  # noqa: E501

        :return: The edge_id of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this EdgeCert.

        ID of the edge this entity belongs to  # noqa: E501

        :param edge_id: The edge_id of this EdgeCert.  # noqa: E501
        :type: str
        """
        if edge_id is None:
            raise ValueError("Invalid value for `edge_id`, must not be `None`")  # noqa: E501

        self._edge_id = edge_id

    @property
    def edge_private_key(self):
        """Gets the edge_private_key of this EdgeCert.  # noqa: E501

        Encrypted private key using per-tenant root CA.  # noqa: E501

        :return: The edge_private_key of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._edge_private_key

    @edge_private_key.setter
    def edge_private_key(self, edge_private_key):
        """Sets the edge_private_key of this EdgeCert.

        Encrypted private key using per-tenant root CA.  # noqa: E501

        :param edge_private_key: The edge_private_key of this EdgeCert.  # noqa: E501
        :type: str
        """
        if edge_private_key is None:
            raise ValueError("Invalid value for `edge_private_key`, must not be `None`")  # noqa: E501

        self._edge_private_key = edge_private_key

    @property
    def id(self):
        """Gets the id of this EdgeCert.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EdgeCert.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this EdgeCert.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def locked(self):
        """Gets the locked of this EdgeCert.  # noqa: E501


        :return: The locked of this EdgeCert.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this EdgeCert.


        :param locked: The locked of this EdgeCert.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def private_key(self):
        """Gets the private_key of this EdgeCert.  # noqa: E501

        Encrypted private key using old/fixed root CA.  # noqa: E501

        :return: The private_key of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this EdgeCert.

        Encrypted private key using old/fixed root CA.  # noqa: E501

        :param private_key: The private_key of this EdgeCert.  # noqa: E501
        :type: str
        """
        if private_key is None:
            raise ValueError("Invalid value for `private_key`, must not be `None`")  # noqa: E501

        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeCert, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeCert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.service_class_schemas import ServiceClassSchemas  # noqa: F401,E501
from kps_api.models.service_class_scope_type import ServiceClassScopeType  # noqa: F401,E501
from kps_api.models.service_class_state_type import ServiceClassStateType  # noqa: F401,E501
from kps_api.models.service_class_tag import ServiceClassTag  # noqa: F401,E501


class ServiceClass(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bindable': 'bool',
        'created_at': 'datetime',
        'description': 'str',
        'id': 'str',
        'min_svc_domain_version': 'str',
        'name': 'str',
        'schemas': 'ServiceClassSchemas',
        'scope': 'ServiceClassScopeType',
        'state': 'ServiceClassStateType',
        'svc_version': 'str',
        'tags': 'list[ServiceClassTag]',
        'type': 'str',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'bindable': 'bindable',
        'created_at': 'createdAt',
        'description': 'description',
        'id': 'id',
        'min_svc_domain_version': 'minSvcDomainVersion',
        'name': 'name',
        'schemas': 'schemas',
        'scope': 'scope',
        'state': 'state',
        'svc_version': 'svcVersion',
        'tags': 'tags',
        'type': 'type',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, bindable=None, created_at=None, description=None, id=None, min_svc_domain_version=None, name=None, schemas=None, scope=None, state=None, svc_version=None, tags=None, type=None, updated_at=None, version=None):  # noqa: E501
        """ServiceClass - a model defined in Swagger"""  # noqa: E501
        self._bindable = None
        self._created_at = None
        self._description = None
        self._id = None
        self._min_svc_domain_version = None
        self._name = None
        self._schemas = None
        self._scope = None
        self._state = None
        self._svc_version = None
        self._tags = None
        self._type = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        self.bindable = bindable
        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        self.min_svc_domain_version = min_svc_domain_version
        self.name = name
        if schemas is not None:
            self.schemas = schemas
        self.scope = scope
        self.state = state
        self.svc_version = svc_version
        if tags is not None:
            self.tags = tags
        self.type = type
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def bindable(self):
        """Gets the bindable of this ServiceClass.  # noqa: E501

        Flag to specify if service binding is supported  # noqa: E501

        :return: The bindable of this ServiceClass.  # noqa: E501
        :rtype: bool
        """
        return self._bindable

    @bindable.setter
    def bindable(self, bindable):
        """Sets the bindable of this ServiceClass.

        Flag to specify if service binding is supported  # noqa: E501

        :param bindable: The bindable of this ServiceClass.  # noqa: E501
        :type: bool
        """
        if bindable is None:
            raise ValueError("Invalid value for `bindable`, must not be `None`")  # noqa: E501

        self._bindable = bindable

    @property
    def created_at(self):
        """Gets the created_at of this ServiceClass.  # noqa: E501


        :return: The created_at of this ServiceClass.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ServiceClass.


        :param created_at: The created_at of this ServiceClass.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this ServiceClass.  # noqa: E501


        :return: The description of this ServiceClass.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServiceClass.


        :param description: The description of this ServiceClass.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ServiceClass.  # noqa: E501


        :return: The id of this ServiceClass.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServiceClass.


        :param id: The id of this ServiceClass.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def min_svc_domain_version(self):
        """Gets the min_svc_domain_version of this ServiceClass.  # noqa: E501

        Minimum version of the Service Domain supporting this Service Class  # noqa: E501

        :return: The min_svc_domain_version of this ServiceClass.  # noqa: E501
        :rtype: str
        """
        return self._min_svc_domain_version

    @min_svc_domain_version.setter
    def min_svc_domain_version(self, min_svc_domain_version):
        """Sets the min_svc_domain_version of this ServiceClass.

        Minimum version of the Service Domain supporting this Service Class  # noqa: E501

        :param min_svc_domain_version: The min_svc_domain_version of this ServiceClass.  # noqa: E501
        :type: str
        """
        if min_svc_domain_version is None:
            raise ValueError("Invalid value for `min_svc_domain_version`, must not be `None`")  # noqa: E501

        self._min_svc_domain_version = min_svc_domain_version

    @property
    def name(self):
        """Gets the name of this ServiceClass.  # noqa: E501


        :return: The name of this ServiceClass.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServiceClass.


        :param name: The name of this ServiceClass.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def schemas(self):
        """Gets the schemas of this ServiceClass.  # noqa: E501


        :return: The schemas of this ServiceClass.  # noqa: E501
        :rtype: ServiceClassSchemas
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """Sets the schemas of this ServiceClass.


        :param schemas: The schemas of this ServiceClass.  # noqa: E501
        :type: ServiceClassSchemas
        """

        self._schemas = schemas

    @property
    def scope(self):
        """Gets the scope of this ServiceClass.  # noqa: E501


        :return: The scope of this ServiceClass.  # noqa: E501
        :rtype: ServiceClassScopeType
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this ServiceClass.


        :param scope: The scope of this ServiceClass.  # noqa: E501
        :type: ServiceClassScopeType
        """
        if scope is None:
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501

        self._scope = scope

    @property
    def state(self):
        """Gets the state of this ServiceClass.  # noqa: E501


        :return: The state of this ServiceClass.  # noqa: E501
        :rtype: ServiceClassStateType
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ServiceClass.


        :param state: The state of this ServiceClass.  # noqa: E501
        :type: ServiceClassStateType
        """
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def svc_version(self):
        """Gets the svc_version of this ServiceClass.  # noqa: E501

        Version of the Service Class type  # noqa: E501

        :return: The svc_version of this ServiceClass.  # noqa: E501
        :rtype: str
        """
        return self._svc_version

    @svc_version.setter
    def svc_version(self, svc_version):
        """Sets the svc_version of this ServiceClass.

        Version of the Service Class type  # noqa: E501

        :param svc_version: The svc_version of this ServiceClass.  # noqa: E501
        :type: str
        """
        if svc_version is None:
            raise ValueError("Invalid value for `svc_version`, must not be `None`")  # noqa: E501

        self._svc_version = svc_version

    @property
    def tags(self):
        """Gets the tags of this ServiceClass.  # noqa: E501

        Tag name can be repeated to hold multiple values. Tags essential = yes/no and category = some category are required  # noqa: E501

        :return: The tags of this ServiceClass.  # noqa: E501
        :rtype: list[ServiceClassTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ServiceClass.

        Tag name can be repeated to hold multiple values. Tags essential = yes/no and category = some category are required  # noqa: E501

        :param tags: The tags of this ServiceClass.  # noqa: E501
        :type: list[ServiceClassTag]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this ServiceClass.  # noqa: E501

        Type of the Service Class e.g Kafka  # noqa: E501

        :return: The type of this ServiceClass.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ServiceClass.

        Type of the Service Class e.g Kafka  # noqa: E501

        :param type: The type of this ServiceClass.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def updated_at(self):
        """Gets the updated_at of this ServiceClass.  # noqa: E501


        :return: The updated_at of this ServiceClass.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ServiceClass.


        :param updated_at: The updated_at of this ServiceClass.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this ServiceClass.  # noqa: E501


        :return: The version of this ServiceClass.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ServiceClass.


        :param version: The version of this ServiceClass.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceClass, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceClass):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AuditLogV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'modifier_id': 'str',
        'modifier_name': 'str',
        'modifier_role': 'str',
        'operation': 'str',
        'operation_type': 'str',
        'payload': 'str',
        'project_id': 'str',
        'project_name': 'str',
        'resource_id': 'str',
        'resource_name': 'str',
        'resource_type': 'str',
        'scope': 'str',
        'service_domain_id': 'str',
        'service_domain_name': 'str',
        'tenant_id': 'str',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'modifier_id': 'modifierID',
        'modifier_name': 'modifierName',
        'modifier_role': 'modifierRole',
        'operation': 'operation',
        'operation_type': 'operationType',
        'payload': 'payload',
        'project_id': 'projectID',
        'project_name': 'projectName',
        'resource_id': 'resourceID',
        'resource_name': 'resourceName',
        'resource_type': 'resourceType',
        'scope': 'scope',
        'service_domain_id': 'serviceDomainID',
        'service_domain_name': 'serviceDomainName',
        'tenant_id': 'tenantID',
        'timestamp': 'timestamp'
    }

    def __init__(self, modifier_id=None, modifier_name=None, modifier_role=None, operation=None, operation_type=None, payload=None, project_id=None, project_name=None, resource_id=None, resource_name=None, resource_type=None, scope=None, service_domain_id=None, service_domain_name=None, tenant_id=None, timestamp=None):  # noqa: E501
        """AuditLogV2 - a model defined in Swagger"""  # noqa: E501
        self._modifier_id = None
        self._modifier_name = None
        self._modifier_role = None
        self._operation = None
        self._operation_type = None
        self._payload = None
        self._project_id = None
        self._project_name = None
        self._resource_id = None
        self._resource_name = None
        self._resource_type = None
        self._scope = None
        self._service_domain_id = None
        self._service_domain_name = None
        self._tenant_id = None
        self._timestamp = None
        self.discriminator = None
        if modifier_id is not None:
            self.modifier_id = modifier_id
        if modifier_name is not None:
            self.modifier_name = modifier_name
        if modifier_role is not None:
            self.modifier_role = modifier_role
        if operation is not None:
            self.operation = operation
        if operation_type is not None:
            self.operation_type = operation_type
        if payload is not None:
            self.payload = payload
        if project_id is not None:
            self.project_id = project_id
        if project_name is not None:
            self.project_name = project_name
        if resource_id is not None:
            self.resource_id = resource_id
        if resource_name is not None:
            self.resource_name = resource_name
        if resource_type is not None:
            self.resource_type = resource_type
        if scope is not None:
            self.scope = scope
        if service_domain_id is not None:
            self.service_domain_id = service_domain_id
        if service_domain_name is not None:
            self.service_domain_name = service_domain_name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def modifier_id(self):
        """Gets the modifier_id of this AuditLogV2.  # noqa: E501


        :return: The modifier_id of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._modifier_id

    @modifier_id.setter
    def modifier_id(self, modifier_id):
        """Sets the modifier_id of this AuditLogV2.


        :param modifier_id: The modifier_id of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._modifier_id = modifier_id

    @property
    def modifier_name(self):
        """Gets the modifier_name of this AuditLogV2.  # noqa: E501


        :return: The modifier_name of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._modifier_name

    @modifier_name.setter
    def modifier_name(self, modifier_name):
        """Sets the modifier_name of this AuditLogV2.


        :param modifier_name: The modifier_name of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._modifier_name = modifier_name

    @property
    def modifier_role(self):
        """Gets the modifier_role of this AuditLogV2.  # noqa: E501


        :return: The modifier_role of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._modifier_role

    @modifier_role.setter
    def modifier_role(self, modifier_role):
        """Sets the modifier_role of this AuditLogV2.


        :param modifier_role: The modifier_role of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._modifier_role = modifier_role

    @property
    def operation(self):
        """Gets the operation of this AuditLogV2.  # noqa: E501


        :return: The operation of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this AuditLogV2.


        :param operation: The operation of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def operation_type(self):
        """Gets the operation_type of this AuditLogV2.  # noqa: E501


        :return: The operation_type of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this AuditLogV2.


        :param operation_type: The operation_type of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._operation_type = operation_type

    @property
    def payload(self):
        """Gets the payload of this AuditLogV2.  # noqa: E501


        :return: The payload of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """Sets the payload of this AuditLogV2.


        :param payload: The payload of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._payload = payload

    @property
    def project_id(self):
        """Gets the project_id of this AuditLogV2.  # noqa: E501


        :return: The project_id of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this AuditLogV2.


        :param project_id: The project_id of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def project_name(self):
        """Gets the project_name of this AuditLogV2.  # noqa: E501


        :return: The project_name of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this AuditLogV2.


        :param project_name: The project_name of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def resource_id(self):
        """Gets the resource_id of this AuditLogV2.  # noqa: E501


        :return: The resource_id of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this AuditLogV2.


        :param resource_id: The resource_id of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def resource_name(self):
        """Gets the resource_name of this AuditLogV2.  # noqa: E501


        :return: The resource_name of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this AuditLogV2.


        :param resource_name: The resource_name of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._resource_name = resource_name

    @property
    def resource_type(self):
        """Gets the resource_type of this AuditLogV2.  # noqa: E501


        :return: The resource_type of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AuditLogV2.


        :param resource_type: The resource_type of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def scope(self):
        """Gets the scope of this AuditLogV2.  # noqa: E501


        :return: The scope of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this AuditLogV2.


        :param scope: The scope of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def service_domain_id(self):
        """Gets the service_domain_id of this AuditLogV2.  # noqa: E501


        :return: The service_domain_id of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._service_domain_id

    @service_domain_id.setter
    def service_domain_id(self, service_domain_id):
        """Sets the service_domain_id of this AuditLogV2.


        :param service_domain_id: The service_domain_id of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._service_domain_id = service_domain_id

    @property
    def service_domain_name(self):
        """Gets the service_domain_name of this AuditLogV2.  # noqa: E501


        :return: The service_domain_name of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._service_domain_name

    @service_domain_name.setter
    def service_domain_name(self, service_domain_name):
        """Sets the service_domain_name of this AuditLogV2.


        :param service_domain_name: The service_domain_name of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._service_domain_name = service_domain_name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AuditLogV2.  # noqa: E501


        :return: The tenant_id of this AuditLogV2.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AuditLogV2.


        :param tenant_id: The tenant_id of this AuditLogV2.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def timestamp(self):
        """Gets the timestamp of this AuditLogV2.  # noqa: E501


        :return: The timestamp of this AuditLogV2.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this AuditLogV2.


        :param timestamp: The timestamp of this AuditLogV2.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuditLogV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from models.function import Function  # noqa: E501
from kps_api.rest import ApiException


class TestFunction(unittest.TestCase):
    """Function unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFunction(self):
        """Test Function"""
        # FIXME: construct object with mandatory attributes with example values
        # model = kps_api.models.function.Function()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class GCPCredential(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_provider_x509_cert_url': 'str',
        'auth_uri': 'str',
        'client_email': 'str',
        'client_id': 'str',
        'client_x509_cert_url': 'str',
        'private_key': 'str',
        'private_key_id': 'str',
        'project_id': 'str',
        'token_uri': 'str',
        'type': 'str'
    }

    attribute_map = {
        'auth_provider_x509_cert_url': 'auth_provider_x509_cert_url',
        'auth_uri': 'auth_uri',
        'client_email': 'client_email',
        'client_id': 'client_id',
        'client_x509_cert_url': 'client_x509_cert_url',
        'private_key': 'private_key',
        'private_key_id': 'private_key_id',
        'project_id': 'project_id',
        'token_uri': 'token_uri',
        'type': 'type'
    }

    def __init__(self, auth_provider_x509_cert_url=None, auth_uri=None, client_email=None, client_id=None, client_x509_cert_url=None, private_key=None, private_key_id=None, project_id=None, token_uri=None, type=None):  # noqa: E501
        """GCPCredential - a model defined in Swagger"""  # noqa: E501
        self._auth_provider_x509_cert_url = None
        self._auth_uri = None
        self._client_email = None
        self._client_id = None
        self._client_x509_cert_url = None
        self._private_key = None
        self._private_key_id = None
        self._project_id = None
        self._token_uri = None
        self._type = None
        self.discriminator = None
        self.auth_provider_x509_cert_url = auth_provider_x509_cert_url
        self.auth_uri = auth_uri
        self.client_email = client_email
        self.client_id = client_id
        self.client_x509_cert_url = client_x509_cert_url
        self.private_key = private_key
        self.private_key_id = private_key_id
        self.project_id = project_id
        self.token_uri = token_uri
        self.type = type

    @property
    def auth_provider_x509_cert_url(self):
        """Gets the auth_provider_x509_cert_url of this GCPCredential.  # noqa: E501

        Google service account key generated using the gcloud command GCP service account key formats depend on when you use the gcloud command or the REST API/client library to generate the key. The gcloud format is supported in this case. Use the key generated using gcloud command as is, for all field values as follows.  Type is set to 'service_account' when you generate the key using gcloud command  # noqa: E501

        :return: The auth_provider_x509_cert_url of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._auth_provider_x509_cert_url

    @auth_provider_x509_cert_url.setter
    def auth_provider_x509_cert_url(self, auth_provider_x509_cert_url):
        """Sets the auth_provider_x509_cert_url of this GCPCredential.

        Google service account key generated using the gcloud command GCP service account key formats depend on when you use the gcloud command or the REST API/client library to generate the key. The gcloud format is supported in this case. Use the key generated using gcloud command as is, for all field values as follows.  Type is set to 'service_account' when you generate the key using gcloud command  # noqa: E501

        :param auth_provider_x509_cert_url: The auth_provider_x509_cert_url of this GCPCredential.  # noqa: E501
        :type: str
        """
        if auth_provider_x509_cert_url is None:
            raise ValueError("Invalid value for `auth_provider_x509_cert_url`, must not be `None`")  # noqa: E501

        self._auth_provider_x509_cert_url = auth_provider_x509_cert_url

    @property
    def auth_uri(self):
        """Gets the auth_uri of this GCPCredential.  # noqa: E501


        :return: The auth_uri of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._auth_uri

    @auth_uri.setter
    def auth_uri(self, auth_uri):
        """Sets the auth_uri of this GCPCredential.


        :param auth_uri: The auth_uri of this GCPCredential.  # noqa: E501
        :type: str
        """
        if auth_uri is None:
            raise ValueError("Invalid value for `auth_uri`, must not be `None`")  # noqa: E501

        self._auth_uri = auth_uri

    @property
    def client_email(self):
        """Gets the client_email of this GCPCredential.  # noqa: E501


        :return: The client_email of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._client_email

    @client_email.setter
    def client_email(self, client_email):
        """Sets the client_email of this GCPCredential.


        :param client_email: The client_email of this GCPCredential.  # noqa: E501
        :type: str
        """
        if client_email is None:
            raise ValueError("Invalid value for `client_email`, must not be `None`")  # noqa: E501

        self._client_email = client_email

    @property
    def client_id(self):
        """Gets the client_id of this GCPCredential.  # noqa: E501


        :return: The client_id of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this GCPCredential.


        :param client_id: The client_id of this GCPCredential.  # noqa: E501
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def client_x509_cert_url(self):
        """Gets the client_x509_cert_url of this GCPCredential.  # noqa: E501


        :return: The client_x509_cert_url of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._client_x509_cert_url

    @client_x509_cert_url.setter
    def client_x509_cert_url(self, client_x509_cert_url):
        """Sets the client_x509_cert_url of this GCPCredential.


        :param client_x509_cert_url: The client_x509_cert_url of this GCPCredential.  # noqa: E501
        :type: str
        """
        if client_x509_cert_url is None:
            raise ValueError("Invalid value for `client_x509_cert_url`, must not be `None`")  # noqa: E501

        self._client_x509_cert_url = client_x509_cert_url

    @property
    def private_key(self):
        """Gets the private_key of this GCPCredential.  # noqa: E501


        :return: The private_key of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this GCPCredential.


        :param private_key: The private_key of this GCPCredential.  # noqa: E501
        :type: str
        """
        if private_key is None:
            raise ValueError("Invalid value for `private_key`, must not be `None`")  # noqa: E501

        self._private_key = private_key

    @property
    def private_key_id(self):
        """Gets the private_key_id of this GCPCredential.  # noqa: E501


        :return: The private_key_id of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._private_key_id

    @private_key_id.setter
    def private_key_id(self, private_key_id):
        """Sets the private_key_id of this GCPCredential.


        :param private_key_id: The private_key_id of this GCPCredential.  # noqa: E501
        :type: str
        """
        if private_key_id is None:
            raise ValueError("Invalid value for `private_key_id`, must not be `None`")  # noqa: E501

        self._private_key_id = private_key_id

    @property
    def project_id(self):
        """Gets the project_id of this GCPCredential.  # noqa: E501

        The project resource is the base-level organizing entity in Google Cloud Platform Specify the unique Id for the project in GCP  # noqa: E501

        :return: The project_id of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GCPCredential.

        The project resource is the base-level organizing entity in Google Cloud Platform Specify the unique Id for the project in GCP  # noqa: E501

        :param project_id: The project_id of this GCPCredential.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def token_uri(self):
        """Gets the token_uri of this GCPCredential.  # noqa: E501


        :return: The token_uri of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._token_uri

    @token_uri.setter
    def token_uri(self, token_uri):
        """Sets the token_uri of this GCPCredential.


        :param token_uri: The token_uri of this GCPCredential.  # noqa: E501
        :type: str
        """
        if token_uri is None:
            raise ValueError("Invalid value for `token_uri`, must not be `None`")  # noqa: E501

        self._token_uri = token_uri

    @property
    def type(self):
        """Gets the type of this GCPCredential.  # noqa: E501


        :return: The type of this GCPCredential.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GCPCredential.


        :param type: The type of this GCPCredential.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GCPCredential, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GCPCredential):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.service_instance_state_type import ServiceInstanceStateType  # noqa: F401,E501


class ServiceInstanceStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'description': 'str',
        'properties': 'dict(str, object)',
        'state': 'ServiceInstanceStateType',
        'svc_domain_id': 'str',
        'svc_instance_id': 'str',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'description': 'description',
        'properties': 'properties',
        'state': 'state',
        'svc_domain_id': 'svcDomainId',
        'svc_instance_id': 'svcInstanceId',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, description=None, properties=None, state=None, svc_domain_id=None, svc_instance_id=None, updated_at=None):  # noqa: E501
        """ServiceInstanceStatus - a model defined in Swagger"""  # noqa: E501
        self._created_at = None
        self._description = None
        self._properties = None
        self._state = None
        self._svc_domain_id = None
        self._svc_instance_id = None
        self._updated_at = None
        self.discriminator = None
        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if properties is not None:
            self.properties = properties
        self.state = state
        self.svc_domain_id = svc_domain_id
        self.svc_instance_id = svc_instance_id
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this ServiceInstanceStatus.  # noqa: E501


        :return: The created_at of this ServiceInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ServiceInstanceStatus.


        :param created_at: The created_at of this ServiceInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this ServiceInstanceStatus.  # noqa: E501


        :return: The description of this ServiceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServiceInstanceStatus.


        :param description: The description of this ServiceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def properties(self):
        """Gets the properties of this ServiceInstanceStatus.  # noqa: E501

        Properties emitted by the instance  # noqa: E501

        :return: The properties of this ServiceInstanceStatus.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ServiceInstanceStatus.

        Properties emitted by the instance  # noqa: E501

        :param properties: The properties of this ServiceInstanceStatus.  # noqa: E501
        :type: dict(str, object)
        """

        self._properties = properties

    @property
    def state(self):
        """Gets the state of this ServiceInstanceStatus.  # noqa: E501


        :return: The state of this ServiceInstanceStatus.  # noqa: E501
        :rtype: ServiceInstanceStateType
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ServiceInstanceStatus.


        :param state: The state of this ServiceInstanceStatus.  # noqa: E501
        :type: ServiceInstanceStateType
        """
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def svc_domain_id(self):
        """Gets the svc_domain_id of this ServiceInstanceStatus.  # noqa: E501


        :return: The svc_domain_id of this ServiceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._svc_domain_id

    @svc_domain_id.setter
    def svc_domain_id(self, svc_domain_id):
        """Sets the svc_domain_id of this ServiceInstanceStatus.


        :param svc_domain_id: The svc_domain_id of this ServiceInstanceStatus.  # noqa: E501
        :type: str
        """
        if svc_domain_id is None:
            raise ValueError("Invalid value for `svc_domain_id`, must not be `None`")  # noqa: E501

        self._svc_domain_id = svc_domain_id

    @property
    def svc_instance_id(self):
        """Gets the svc_instance_id of this ServiceInstanceStatus.  # noqa: E501


        :return: The svc_instance_id of this ServiceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._svc_instance_id

    @svc_instance_id.setter
    def svc_instance_id(self, svc_instance_id):
        """Sets the svc_instance_id of this ServiceInstanceStatus.


        :param svc_instance_id: The svc_instance_id of this ServiceInstanceStatus.  # noqa: E501
        :type: str
        """
        if svc_instance_id is None:
            raise ValueError("Invalid value for `svc_instance_id`, must not be `None`")  # noqa: E501

        self._svc_instance_id = svc_instance_id

    @property
    def updated_at(self):
        """Gets the updated_at of this ServiceInstanceStatus.  # noqa: E501


        :return: The updated_at of this ServiceInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ServiceInstanceStatus.


        :param updated_at: The updated_at of this ServiceInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceInstanceStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceInstanceStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.connector_class_api import ConnectorClassApi  # noqa: E501
from kps_api.rest import ApiException


class TestConnectorClassApi(unittest.TestCase):
    """ConnectorClassApi unit test stubs"""

    def setUp(self):
        self.api = api.connector_class_api.ConnectorClassApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_connector_class_create(self):
        """Test case for connector_class_create

        Create a connector class.  # noqa: E501
        """
        pass

    def test_connector_class_delete(self):
        """Test case for connector_class_delete

        Delete a specific connector class.  # noqa: E501
        """
        pass

    def test_connector_class_get(self):
        """Test case for connector_class_get

        Get a connector class by ID.  # noqa: E501
        """
        pass

    def test_connector_class_list(self):
        """Test case for connector_class_list

        Get all connector class.  # noqa: E501
        """
        pass

    def test_connector_class_update(self):
        """Test case for connector_class_update

        Update a connector class.  # noqa: E501
        """
        pass

    def test_connector_instances_by_class_id_list(self):
        """Test case for connector_instances_by_class_id_list

        Get all connector instances by class id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.ebs_storage_profile_config import EBSStorageProfileConfig  # noqa: F401,E501
from kps_api.models.nutanix_volumes_storage_profile_config import NutanixVolumesStorageProfileConfig  # noqa: F401,E501
from kps_api.models.v_sphere_storage_profile_config import VSphereStorageProfileConfig  # noqa: F401,E501


class StorageProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ebs_storage_config': 'EBSStorageProfileConfig',
        'id': 'str',
        'is_default': 'bool',
        'name': 'str',
        'nutanix_volumes_config': 'NutanixVolumesStorageProfileConfig',
        'type': 'str',
        'v_sphere_storage_config': 'VSphereStorageProfileConfig'
    }

    attribute_map = {
        'ebs_storage_config': 'ebsStorageConfig',
        'id': 'id',
        'is_default': 'isDefault',
        'name': 'name',
        'nutanix_volumes_config': 'nutanixVolumesConfig',
        'type': 'type',
        'v_sphere_storage_config': 'vSphereStorageConfig'
    }

    def __init__(self, ebs_storage_config=None, id=None, is_default=None, name=None, nutanix_volumes_config=None, type=None, v_sphere_storage_config=None):  # noqa: E501
        """StorageProfile - a model defined in Swagger"""  # noqa: E501
        self._ebs_storage_config = None
        self._id = None
        self._is_default = None
        self._name = None
        self._nutanix_volumes_config = None
        self._type = None
        self._v_sphere_storage_config = None
        self.discriminator = None
        if ebs_storage_config is not None:
            self.ebs_storage_config = ebs_storage_config
        if id is not None:
            self.id = id
        if is_default is not None:
            self.is_default = is_default
        self.name = name
        if nutanix_volumes_config is not None:
            self.nutanix_volumes_config = nutanix_volumes_config
        self.type = type
        if v_sphere_storage_config is not None:
            self.v_sphere_storage_config = v_sphere_storage_config

    @property
    def ebs_storage_config(self):
        """Gets the ebs_storage_config of this StorageProfile.  # noqa: E501


        :return: The ebs_storage_config of this StorageProfile.  # noqa: E501
        :rtype: EBSStorageProfileConfig
        """
        return self._ebs_storage_config

    @ebs_storage_config.setter
    def ebs_storage_config(self, ebs_storage_config):
        """Sets the ebs_storage_config of this StorageProfile.


        :param ebs_storage_config: The ebs_storage_config of this StorageProfile.  # noqa: E501
        :type: EBSStorageProfileConfig
        """

        self._ebs_storage_config = ebs_storage_config

    @property
    def id(self):
        """Gets the id of this StorageProfile.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this StorageProfile.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StorageProfile.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this StorageProfile.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_default(self):
        """Gets the is_default of this StorageProfile.  # noqa: E501

        Flag to specify if it is default storage profile  # noqa: E501

        :return: The is_default of this StorageProfile.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this StorageProfile.

        Flag to specify if it is default storage profile  # noqa: E501

        :param is_default: The is_default of this StorageProfile.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def name(self):
        """Gets the name of this StorageProfile.  # noqa: E501

        Name for the storage profile.  # noqa: E501

        :return: The name of this StorageProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageProfile.

        Name for the storage profile.  # noqa: E501

        :param name: The name of this StorageProfile.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def nutanix_volumes_config(self):
        """Gets the nutanix_volumes_config of this StorageProfile.  # noqa: E501


        :return: The nutanix_volumes_config of this StorageProfile.  # noqa: E501
        :rtype: NutanixVolumesStorageProfileConfig
        """
        return self._nutanix_volumes_config

    @nutanix_volumes_config.setter
    def nutanix_volumes_config(self, nutanix_volumes_config):
        """Sets the nutanix_volumes_config of this StorageProfile.


        :param nutanix_volumes_config: The nutanix_volumes_config of this StorageProfile.  # noqa: E501
        :type: NutanixVolumesStorageProfileConfig
        """

        self._nutanix_volumes_config = nutanix_volumes_config

    @property
    def type(self):
        """Gets the type of this StorageProfile.  # noqa: E501

        Storage type for this Storage profile.  # noqa: E501

        :return: The type of this StorageProfile.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StorageProfile.

        Storage type for this Storage profile.  # noqa: E501

        :param type: The type of this StorageProfile.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["NutanixVolumes", "EBS", "vSphere"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def v_sphere_storage_config(self):
        """Gets the v_sphere_storage_config of this StorageProfile.  # noqa: E501


        :return: The v_sphere_storage_config of this StorageProfile.  # noqa: E501
        :rtype: VSphereStorageProfileConfig
        """
        return self._v_sphere_storage_config

    @v_sphere_storage_config.setter
    def v_sphere_storage_config(self, v_sphere_storage_config):
        """Sets the v_sphere_storage_config of this StorageProfile.


        :param v_sphere_storage_config: The v_sphere_storage_config of this StorageProfile.  # noqa: E501
        :type: VSphereStorageProfileConfig
        """

        self._v_sphere_storage_config = v_sphere_storage_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StorageProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.protocol_traffic import ProtocolTraffic  # noqa: F401,E501
from kps_api.models.service_name import ServiceName  # noqa: F401,E501


class NodeData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app': 'str',
        'dest_services': 'list[ServiceName]',
        'has_cb': 'bool',
        'has_missing_sc': 'bool',
        'has_vs': 'bool',
        'id': 'str',
        'is_dead': 'bool',
        'is_group': 'str',
        'is_inaccessible': 'bool',
        'is_misconfigured': 'str',
        'is_outside': 'bool',
        'is_root': 'bool',
        'is_service_entry': 'str',
        'is_unused': 'bool',
        'namespace': 'str',
        'node_type': 'str',
        'parent': 'str',
        'service': 'str',
        'traffic': 'list[ProtocolTraffic]',
        'version': 'str',
        'workload': 'str'
    }

    attribute_map = {
        'app': 'app',
        'dest_services': 'destServices',
        'has_cb': 'hasCB',
        'has_missing_sc': 'hasMissingSC',
        'has_vs': 'hasVS',
        'id': 'id',
        'is_dead': 'isDead',
        'is_group': 'isGroup',
        'is_inaccessible': 'isInaccessible',
        'is_misconfigured': 'isMisconfigured',
        'is_outside': 'isOutside',
        'is_root': 'isRoot',
        'is_service_entry': 'isServiceEntry',
        'is_unused': 'isUnused',
        'namespace': 'namespace',
        'node_type': 'nodeType',
        'parent': 'parent',
        'service': 'service',
        'traffic': 'traffic',
        'version': 'version',
        'workload': 'workload'
    }

    def __init__(self, app=None, dest_services=None, has_cb=None, has_missing_sc=None, has_vs=None, id=None, is_dead=None, is_group=None, is_inaccessible=None, is_misconfigured=None, is_outside=None, is_root=None, is_service_entry=None, is_unused=None, namespace=None, node_type=None, parent=None, service=None, traffic=None, version=None, workload=None):  # noqa: E501
        """NodeData - a model defined in Swagger"""  # noqa: E501
        self._app = None
        self._dest_services = None
        self._has_cb = None
        self._has_missing_sc = None
        self._has_vs = None
        self._id = None
        self._is_dead = None
        self._is_group = None
        self._is_inaccessible = None
        self._is_misconfigured = None
        self._is_outside = None
        self._is_root = None
        self._is_service_entry = None
        self._is_unused = None
        self._namespace = None
        self._node_type = None
        self._parent = None
        self._service = None
        self._traffic = None
        self._version = None
        self._workload = None
        self.discriminator = None
        if app is not None:
            self.app = app
        if dest_services is not None:
            self.dest_services = dest_services
        if has_cb is not None:
            self.has_cb = has_cb
        if has_missing_sc is not None:
            self.has_missing_sc = has_missing_sc
        if has_vs is not None:
            self.has_vs = has_vs
        if id is not None:
            self.id = id
        if is_dead is not None:
            self.is_dead = is_dead
        if is_group is not None:
            self.is_group = is_group
        if is_inaccessible is not None:
            self.is_inaccessible = is_inaccessible
        if is_misconfigured is not None:
            self.is_misconfigured = is_misconfigured
        if is_outside is not None:
            self.is_outside = is_outside
        if is_root is not None:
            self.is_root = is_root
        if is_service_entry is not None:
            self.is_service_entry = is_service_entry
        if is_unused is not None:
            self.is_unused = is_unused
        if namespace is not None:
            self.namespace = namespace
        if node_type is not None:
            self.node_type = node_type
        if parent is not None:
            self.parent = parent
        if service is not None:
            self.service = service
        if traffic is not None:
            self.traffic = traffic
        if version is not None:
            self.version = version
        if workload is not None:
            self.workload = workload

    @property
    def app(self):
        """Gets the app of this NodeData.  # noqa: E501


        :return: The app of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this NodeData.


        :param app: The app of this NodeData.  # noqa: E501
        :type: str
        """

        self._app = app

    @property
    def dest_services(self):
        """Gets the dest_services of this NodeData.  # noqa: E501


        :return: The dest_services of this NodeData.  # noqa: E501
        :rtype: list[ServiceName]
        """
        return self._dest_services

    @dest_services.setter
    def dest_services(self, dest_services):
        """Sets the dest_services of this NodeData.


        :param dest_services: The dest_services of this NodeData.  # noqa: E501
        :type: list[ServiceName]
        """

        self._dest_services = dest_services

    @property
    def has_cb(self):
        """Gets the has_cb of this NodeData.  # noqa: E501


        :return: The has_cb of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._has_cb

    @has_cb.setter
    def has_cb(self, has_cb):
        """Sets the has_cb of this NodeData.


        :param has_cb: The has_cb of this NodeData.  # noqa: E501
        :type: bool
        """

        self._has_cb = has_cb

    @property
    def has_missing_sc(self):
        """Gets the has_missing_sc of this NodeData.  # noqa: E501


        :return: The has_missing_sc of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._has_missing_sc

    @has_missing_sc.setter
    def has_missing_sc(self, has_missing_sc):
        """Sets the has_missing_sc of this NodeData.


        :param has_missing_sc: The has_missing_sc of this NodeData.  # noqa: E501
        :type: bool
        """

        self._has_missing_sc = has_missing_sc

    @property
    def has_vs(self):
        """Gets the has_vs of this NodeData.  # noqa: E501


        :return: The has_vs of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._has_vs

    @has_vs.setter
    def has_vs(self, has_vs):
        """Sets the has_vs of this NodeData.


        :param has_vs: The has_vs of this NodeData.  # noqa: E501
        :type: bool
        """

        self._has_vs = has_vs

    @property
    def id(self):
        """Gets the id of this NodeData.  # noqa: E501

        Cytoscape Fields  # noqa: E501

        :return: The id of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NodeData.

        Cytoscape Fields  # noqa: E501

        :param id: The id of this NodeData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_dead(self):
        """Gets the is_dead of this NodeData.  # noqa: E501


        :return: The is_dead of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._is_dead

    @is_dead.setter
    def is_dead(self, is_dead):
        """Sets the is_dead of this NodeData.


        :param is_dead: The is_dead of this NodeData.  # noqa: E501
        :type: bool
        """

        self._is_dead = is_dead

    @property
    def is_group(self):
        """Gets the is_group of this NodeData.  # noqa: E501


        :return: The is_group of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._is_group

    @is_group.setter
    def is_group(self, is_group):
        """Sets the is_group of this NodeData.


        :param is_group: The is_group of this NodeData.  # noqa: E501
        :type: str
        """

        self._is_group = is_group

    @property
    def is_inaccessible(self):
        """Gets the is_inaccessible of this NodeData.  # noqa: E501


        :return: The is_inaccessible of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._is_inaccessible

    @is_inaccessible.setter
    def is_inaccessible(self, is_inaccessible):
        """Sets the is_inaccessible of this NodeData.


        :param is_inaccessible: The is_inaccessible of this NodeData.  # noqa: E501
        :type: bool
        """

        self._is_inaccessible = is_inaccessible

    @property
    def is_misconfigured(self):
        """Gets the is_misconfigured of this NodeData.  # noqa: E501


        :return: The is_misconfigured of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._is_misconfigured

    @is_misconfigured.setter
    def is_misconfigured(self, is_misconfigured):
        """Sets the is_misconfigured of this NodeData.


        :param is_misconfigured: The is_misconfigured of this NodeData.  # noqa: E501
        :type: str
        """

        self._is_misconfigured = is_misconfigured

    @property
    def is_outside(self):
        """Gets the is_outside of this NodeData.  # noqa: E501


        :return: The is_outside of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._is_outside

    @is_outside.setter
    def is_outside(self, is_outside):
        """Sets the is_outside of this NodeData.


        :param is_outside: The is_outside of this NodeData.  # noqa: E501
        :type: bool
        """

        self._is_outside = is_outside

    @property
    def is_root(self):
        """Gets the is_root of this NodeData.  # noqa: E501


        :return: The is_root of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._is_root

    @is_root.setter
    def is_root(self, is_root):
        """Sets the is_root of this NodeData.


        :param is_root: The is_root of this NodeData.  # noqa: E501
        :type: bool
        """

        self._is_root = is_root

    @property
    def is_service_entry(self):
        """Gets the is_service_entry of this NodeData.  # noqa: E501


        :return: The is_service_entry of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._is_service_entry

    @is_service_entry.setter
    def is_service_entry(self, is_service_entry):
        """Sets the is_service_entry of this NodeData.


        :param is_service_entry: The is_service_entry of this NodeData.  # noqa: E501
        :type: str
        """

        self._is_service_entry = is_service_entry

    @property
    def is_unused(self):
        """Gets the is_unused of this NodeData.  # noqa: E501


        :return: The is_unused of this NodeData.  # noqa: E501
        :rtype: bool
        """
        return self._is_unused

    @is_unused.setter
    def is_unused(self, is_unused):
        """Sets the is_unused of this NodeData.


        :param is_unused: The is_unused of this NodeData.  # noqa: E501
        :type: bool
        """

        self._is_unused = is_unused

    @property
    def namespace(self):
        """Gets the namespace of this NodeData.  # noqa: E501


        :return: The namespace of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this NodeData.


        :param namespace: The namespace of this NodeData.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def node_type(self):
        """Gets the node_type of this NodeData.  # noqa: E501

        App Fields (not required by Cytoscape)  # noqa: E501

        :return: The node_type of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this NodeData.

        App Fields (not required by Cytoscape)  # noqa: E501

        :param node_type: The node_type of this NodeData.  # noqa: E501
        :type: str
        """

        self._node_type = node_type

    @property
    def parent(self):
        """Gets the parent of this NodeData.  # noqa: E501


        :return: The parent of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this NodeData.


        :param parent: The parent of this NodeData.  # noqa: E501
        :type: str
        """

        self._parent = parent

    @property
    def service(self):
        """Gets the service of this NodeData.  # noqa: E501


        :return: The service of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this NodeData.


        :param service: The service of this NodeData.  # noqa: E501
        :type: str
        """

        self._service = service

    @property
    def traffic(self):
        """Gets the traffic of this NodeData.  # noqa: E501


        :return: The traffic of this NodeData.  # noqa: E501
        :rtype: list[ProtocolTraffic]
        """
        return self._traffic

    @traffic.setter
    def traffic(self, traffic):
        """Sets the traffic of this NodeData.


        :param traffic: The traffic of this NodeData.  # noqa: E501
        :type: list[ProtocolTraffic]
        """

        self._traffic = traffic

    @property
    def version(self):
        """Gets the version of this NodeData.  # noqa: E501


        :return: The version of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this NodeData.


        :param version: The version of this NodeData.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def workload(self):
        """Gets the workload of this NodeData.  # noqa: E501


        :return: The workload of this NodeData.  # noqa: E501
        :rtype: str
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this NodeData.


        :param workload: The workload of this NodeData.  # noqa: E501
        :type: str
        """

        self._workload = workload

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.connector_class_type import ConnectorClassType  # noqa: F401,E501
from kps_api.models.connector_parameters_schema import ConnectorParametersSchema  # noqa: F401,E501


class ConnectorClass(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'config_parameter_schema': 'ConnectorParametersSchema',
        'connector_version': 'str',
        'description': 'str',
        'id': 'str',
        'min_svc_domain_version': 'str',
        'name': 'str',
        'static_parameter_schema': 'ConnectorParametersSchema',
        'stream_parameter_schema': 'ConnectorParametersSchema',
        'type': 'ConnectorClassType',
        'yaml_data': 'str'
    }

    attribute_map = {
        'config_parameter_schema': 'configParameterSchema',
        'connector_version': 'connectorVersion',
        'description': 'description',
        'id': 'id',
        'min_svc_domain_version': 'minSvcDomainVersion',
        'name': 'name',
        'static_parameter_schema': 'staticParameterSchema',
        'stream_parameter_schema': 'streamParameterSchema',
        'type': 'type',
        'yaml_data': 'yamlData'
    }

    def __init__(self, config_parameter_schema=None, connector_version=None, description=None, id=None, min_svc_domain_version=None, name=None, static_parameter_schema=None, stream_parameter_schema=None, type=None, yaml_data=None):  # noqa: E501
        """ConnectorClass - a model defined in Swagger"""  # noqa: E501
        self._config_parameter_schema = None
        self._connector_version = None
        self._description = None
        self._id = None
        self._min_svc_domain_version = None
        self._name = None
        self._static_parameter_schema = None
        self._stream_parameter_schema = None
        self._type = None
        self._yaml_data = None
        self.discriminator = None
        if config_parameter_schema is not None:
            self.config_parameter_schema = config_parameter_schema
        self.connector_version = connector_version
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if min_svc_domain_version is not None:
            self.min_svc_domain_version = min_svc_domain_version
        self.name = name
        if static_parameter_schema is not None:
            self.static_parameter_schema = static_parameter_schema
        if stream_parameter_schema is not None:
            self.stream_parameter_schema = stream_parameter_schema
        self.type = type
        self.yaml_data = yaml_data

    @property
    def config_parameter_schema(self):
        """Gets the config_parameter_schema of this ConnectorClass.  # noqa: E501


        :return: The config_parameter_schema of this ConnectorClass.  # noqa: E501
        :rtype: ConnectorParametersSchema
        """
        return self._config_parameter_schema

    @config_parameter_schema.setter
    def config_parameter_schema(self, config_parameter_schema):
        """Sets the config_parameter_schema of this ConnectorClass.


        :param config_parameter_schema: The config_parameter_schema of this ConnectorClass.  # noqa: E501
        :type: ConnectorParametersSchema
        """

        self._config_parameter_schema = config_parameter_schema

    @property
    def connector_version(self):
        """Gets the connector_version of this ConnectorClass.  # noqa: E501

        External version of a connector. It is possible to have multiple connectors with the same name, but different versions.  # noqa: E501

        :return: The connector_version of this ConnectorClass.  # noqa: E501
        :rtype: str
        """
        return self._connector_version

    @connector_version.setter
    def connector_version(self, connector_version):
        """Sets the connector_version of this ConnectorClass.

        External version of a connector. It is possible to have multiple connectors with the same name, but different versions.  # noqa: E501

        :param connector_version: The connector_version of this ConnectorClass.  # noqa: E501
        :type: str
        """
        if connector_version is None:
            raise ValueError("Invalid value for `connector_version`, must not be `None`")  # noqa: E501

        self._connector_version = connector_version

    @property
    def description(self):
        """Gets the description of this ConnectorClass.  # noqa: E501


        :return: The description of this ConnectorClass.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ConnectorClass.


        :param description: The description of this ConnectorClass.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ConnectorClass.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this ConnectorClass.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectorClass.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this ConnectorClass.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def min_svc_domain_version(self):
        """Gets the min_svc_domain_version of this ConnectorClass.  # noqa: E501


        :return: The min_svc_domain_version of this ConnectorClass.  # noqa: E501
        :rtype: str
        """
        return self._min_svc_domain_version

    @min_svc_domain_version.setter
    def min_svc_domain_version(self, min_svc_domain_version):
        """Sets the min_svc_domain_version of this ConnectorClass.


        :param min_svc_domain_version: The min_svc_domain_version of this ConnectorClass.  # noqa: E501
        :type: str
        """

        self._min_svc_domain_version = min_svc_domain_version

    @property
    def name(self):
        """Gets the name of this ConnectorClass.  # noqa: E501


        :return: The name of this ConnectorClass.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConnectorClass.


        :param name: The name of this ConnectorClass.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def static_parameter_schema(self):
        """Gets the static_parameter_schema of this ConnectorClass.  # noqa: E501


        :return: The static_parameter_schema of this ConnectorClass.  # noqa: E501
        :rtype: ConnectorParametersSchema
        """
        return self._static_parameter_schema

    @static_parameter_schema.setter
    def static_parameter_schema(self, static_parameter_schema):
        """Sets the static_parameter_schema of this ConnectorClass.


        :param static_parameter_schema: The static_parameter_schema of this ConnectorClass.  # noqa: E501
        :type: ConnectorParametersSchema
        """

        self._static_parameter_schema = static_parameter_schema

    @property
    def stream_parameter_schema(self):
        """Gets the stream_parameter_schema of this ConnectorClass.  # noqa: E501


        :return: The stream_parameter_schema of this ConnectorClass.  # noqa: E501
        :rtype: ConnectorParametersSchema
        """
        return self._stream_parameter_schema

    @stream_parameter_schema.setter
    def stream_parameter_schema(self, stream_parameter_schema):
        """Sets the stream_parameter_schema of this ConnectorClass.


        :param stream_parameter_schema: The stream_parameter_schema of this ConnectorClass.  # noqa: E501
        :type: ConnectorParametersSchema
        """

        self._stream_parameter_schema = stream_parameter_schema

    @property
    def type(self):
        """Gets the type of this ConnectorClass.  # noqa: E501


        :return: The type of this ConnectorClass.  # noqa: E501
        :rtype: ConnectorClassType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ConnectorClass.


        :param type: The type of this ConnectorClass.  # noqa: E501
        :type: ConnectorClassType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def yaml_data(self):
        """Gets the yaml_data of this ConnectorClass.  # noqa: E501

        The YAML content for the application.  # noqa: E501

        :return: The yaml_data of this ConnectorClass.  # noqa: E501
        :rtype: str
        """
        return self._yaml_data

    @yaml_data.setter
    def yaml_data(self, yaml_data):
        """Sets the yaml_data of this ConnectorClass.

        The YAML content for the application.  # noqa: E501

        :param yaml_data: The yaml_data of this ConnectorClass.  # noqa: E501
        :type: str
        """
        if yaml_data is None:
            raise ValueError("Invalid value for `yaml_data`, must not be `None`")  # noqa: E501

        self._yaml_data = yaml_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConnectorClass, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorClass):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.additional_item import AdditionalItem  # noqa: F401,E501
from kps_api.models.pods import Pods  # noqa: F401,E501
from kps_api.models.runtime import Runtime  # noqa: F401,E501
from kps_api.models.services import Services  # noqa: F401,E501


class Workload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_detail_sample': 'AdditionalItem',
        'additional_details': 'list[AdditionalItem]',
        'app_label': 'bool',
        'available_replicas': 'int',
        'created_at': 'str',
        'current_replicas': 'int',
        'desired_replicas': 'int',
        'istio_sidecar': 'bool',
        'labels': 'dict(str, str)',
        'name': 'str',
        'pod_count': 'int',
        'pods': 'Pods',
        'resource_version': 'str',
        'runtimes': 'list[Runtime]',
        'services': 'Services',
        'type': 'str',
        'version_label': 'bool'
    }

    attribute_map = {
        'additional_detail_sample': 'additionalDetailSample',
        'additional_details': 'additionalDetails',
        'app_label': 'appLabel',
        'available_replicas': 'availableReplicas',
        'created_at': 'createdAt',
        'current_replicas': 'currentReplicas',
        'desired_replicas': 'desiredReplicas',
        'istio_sidecar': 'istioSidecar',
        'labels': 'labels',
        'name': 'name',
        'pod_count': 'podCount',
        'pods': 'pods',
        'resource_version': 'resourceVersion',
        'runtimes': 'runtimes',
        'services': 'services',
        'type': 'type',
        'version_label': 'versionLabel'
    }

    def __init__(self, additional_detail_sample=None, additional_details=None, app_label=None, available_replicas=None, created_at=None, current_replicas=None, desired_replicas=None, istio_sidecar=None, labels=None, name=None, pod_count=None, pods=None, resource_version=None, runtimes=None, services=None, type=None, version_label=None):  # noqa: E501
        """Workload - a model defined in Swagger"""  # noqa: E501
        self._additional_detail_sample = None
        self._additional_details = None
        self._app_label = None
        self._available_replicas = None
        self._created_at = None
        self._current_replicas = None
        self._desired_replicas = None
        self._istio_sidecar = None
        self._labels = None
        self._name = None
        self._pod_count = None
        self._pods = None
        self._resource_version = None
        self._runtimes = None
        self._services = None
        self._type = None
        self._version_label = None
        self.discriminator = None
        if additional_detail_sample is not None:
            self.additional_detail_sample = additional_detail_sample
        if additional_details is not None:
            self.additional_details = additional_details
        self.app_label = app_label
        self.available_replicas = available_replicas
        self.created_at = created_at
        self.current_replicas = current_replicas
        self.desired_replicas = desired_replicas
        self.istio_sidecar = istio_sidecar
        if labels is not None:
            self.labels = labels
        self.name = name
        self.pod_count = pod_count
        if pods is not None:
            self.pods = pods
        self.resource_version = resource_version
        if runtimes is not None:
            self.runtimes = runtimes
        if services is not None:
            self.services = services
        self.type = type
        self.version_label = version_label

    @property
    def additional_detail_sample(self):
        """Gets the additional_detail_sample of this Workload.  # noqa: E501


        :return: The additional_detail_sample of this Workload.  # noqa: E501
        :rtype: AdditionalItem
        """
        return self._additional_detail_sample

    @additional_detail_sample.setter
    def additional_detail_sample(self, additional_detail_sample):
        """Sets the additional_detail_sample of this Workload.


        :param additional_detail_sample: The additional_detail_sample of this Workload.  # noqa: E501
        :type: AdditionalItem
        """

        self._additional_detail_sample = additional_detail_sample

    @property
    def additional_details(self):
        """Gets the additional_details of this Workload.  # noqa: E501

        Additional details to display, such as configured annotations  # noqa: E501

        :return: The additional_details of this Workload.  # noqa: E501
        :rtype: list[AdditionalItem]
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """Sets the additional_details of this Workload.

        Additional details to display, such as configured annotations  # noqa: E501

        :param additional_details: The additional_details of this Workload.  # noqa: E501
        :type: list[AdditionalItem]
        """

        self._additional_details = additional_details

    @property
    def app_label(self):
        """Gets the app_label of this Workload.  # noqa: E501

        Define if Pods related to this Workload has the label App  # noqa: E501

        :return: The app_label of this Workload.  # noqa: E501
        :rtype: bool
        """
        return self._app_label

    @app_label.setter
    def app_label(self, app_label):
        """Sets the app_label of this Workload.

        Define if Pods related to this Workload has the label App  # noqa: E501

        :param app_label: The app_label of this Workload.  # noqa: E501
        :type: bool
        """
        if app_label is None:
            raise ValueError("Invalid value for `app_label`, must not be `None`")  # noqa: E501

        self._app_label = app_label

    @property
    def available_replicas(self):
        """Gets the available_replicas of this Workload.  # noqa: E501

        Number of available replicas  # noqa: E501

        :return: The available_replicas of this Workload.  # noqa: E501
        :rtype: int
        """
        return self._available_replicas

    @available_replicas.setter
    def available_replicas(self, available_replicas):
        """Sets the available_replicas of this Workload.

        Number of available replicas  # noqa: E501

        :param available_replicas: The available_replicas of this Workload.  # noqa: E501
        :type: int
        """
        if available_replicas is None:
            raise ValueError("Invalid value for `available_replicas`, must not be `None`")  # noqa: E501

        self._available_replicas = available_replicas

    @property
    def created_at(self):
        """Gets the created_at of this Workload.  # noqa: E501

        Creation timestamp (in RFC3339 format)  # noqa: E501

        :return: The created_at of this Workload.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Workload.

        Creation timestamp (in RFC3339 format)  # noqa: E501

        :param created_at: The created_at of this Workload.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def current_replicas(self):
        """Gets the current_replicas of this Workload.  # noqa: E501

        Number of current replicas pods that matches controller selector labels  # noqa: E501

        :return: The current_replicas of this Workload.  # noqa: E501
        :rtype: int
        """
        return self._current_replicas

    @current_replicas.setter
    def current_replicas(self, current_replicas):
        """Sets the current_replicas of this Workload.

        Number of current replicas pods that matches controller selector labels  # noqa: E501

        :param current_replicas: The current_replicas of this Workload.  # noqa: E501
        :type: int
        """
        if current_replicas is None:
            raise ValueError("Invalid value for `current_replicas`, must not be `None`")  # noqa: E501

        self._current_replicas = current_replicas

    @property
    def desired_replicas(self):
        """Gets the desired_replicas of this Workload.  # noqa: E501

        Number of desired replicas defined by the user in the controller Spec  # noqa: E501

        :return: The desired_replicas of this Workload.  # noqa: E501
        :rtype: int
        """
        return self._desired_replicas

    @desired_replicas.setter
    def desired_replicas(self, desired_replicas):
        """Sets the desired_replicas of this Workload.

        Number of desired replicas defined by the user in the controller Spec  # noqa: E501

        :param desired_replicas: The desired_replicas of this Workload.  # noqa: E501
        :type: int
        """
        if desired_replicas is None:
            raise ValueError("Invalid value for `desired_replicas`, must not be `None`")  # noqa: E501

        self._desired_replicas = desired_replicas

    @property
    def istio_sidecar(self):
        """Gets the istio_sidecar of this Workload.  # noqa: E501

        Define if Pods related to this Workload has an IstioSidecar deployed  # noqa: E501

        :return: The istio_sidecar of this Workload.  # noqa: E501
        :rtype: bool
        """
        return self._istio_sidecar

    @istio_sidecar.setter
    def istio_sidecar(self, istio_sidecar):
        """Sets the istio_sidecar of this Workload.

        Define if Pods related to this Workload has an IstioSidecar deployed  # noqa: E501

        :param istio_sidecar: The istio_sidecar of this Workload.  # noqa: E501
        :type: bool
        """
        if istio_sidecar is None:
            raise ValueError("Invalid value for `istio_sidecar`, must not be `None`")  # noqa: E501

        self._istio_sidecar = istio_sidecar

    @property
    def labels(self):
        """Gets the labels of this Workload.  # noqa: E501

        Workload labels  # noqa: E501

        :return: The labels of this Workload.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this Workload.

        Workload labels  # noqa: E501

        :param labels: The labels of this Workload.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this Workload.  # noqa: E501

        Name of the workload  # noqa: E501

        :return: The name of this Workload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Workload.

        Name of the workload  # noqa: E501

        :param name: The name of this Workload.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def pod_count(self):
        """Gets the pod_count of this Workload.  # noqa: E501

        Number of current workload pods  # noqa: E501

        :return: The pod_count of this Workload.  # noqa: E501
        :rtype: int
        """
        return self._pod_count

    @pod_count.setter
    def pod_count(self, pod_count):
        """Sets the pod_count of this Workload.

        Number of current workload pods  # noqa: E501

        :param pod_count: The pod_count of this Workload.  # noqa: E501
        :type: int
        """
        if pod_count is None:
            raise ValueError("Invalid value for `pod_count`, must not be `None`")  # noqa: E501

        self._pod_count = pod_count

    @property
    def pods(self):
        """Gets the pods of this Workload.  # noqa: E501


        :return: The pods of this Workload.  # noqa: E501
        :rtype: Pods
        """
        return self._pods

    @pods.setter
    def pods(self, pods):
        """Sets the pods of this Workload.


        :param pods: The pods of this Workload.  # noqa: E501
        :type: Pods
        """

        self._pods = pods

    @property
    def resource_version(self):
        """Gets the resource_version of this Workload.  # noqa: E501

        Kubernetes ResourceVersion  # noqa: E501

        :return: The resource_version of this Workload.  # noqa: E501
        :rtype: str
        """
        return self._resource_version

    @resource_version.setter
    def resource_version(self, resource_version):
        """Sets the resource_version of this Workload.

        Kubernetes ResourceVersion  # noqa: E501

        :param resource_version: The resource_version of this Workload.  # noqa: E501
        :type: str
        """
        if resource_version is None:
            raise ValueError("Invalid value for `resource_version`, must not be `None`")  # noqa: E501

        self._resource_version = resource_version

    @property
    def runtimes(self):
        """Gets the runtimes of this Workload.  # noqa: E501

        Runtimes and associated dashboards  # noqa: E501

        :return: The runtimes of this Workload.  # noqa: E501
        :rtype: list[Runtime]
        """
        return self._runtimes

    @runtimes.setter
    def runtimes(self, runtimes):
        """Sets the runtimes of this Workload.

        Runtimes and associated dashboards  # noqa: E501

        :param runtimes: The runtimes of this Workload.  # noqa: E501
        :type: list[Runtime]
        """

        self._runtimes = runtimes

    @property
    def services(self):
        """Gets the services of this Workload.  # noqa: E501


        :return: The services of this Workload.  # noqa: E501
        :rtype: Services
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this Workload.


        :param services: The services of this Workload.  # noqa: E501
        :type: Services
        """

        self._services = services

    @property
    def type(self):
        """Gets the type of this Workload.  # noqa: E501

        Type of the workload  # noqa: E501

        :return: The type of this Workload.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Workload.

        Type of the workload  # noqa: E501

        :param type: The type of this Workload.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def version_label(self):
        """Gets the version_label of this Workload.  # noqa: E501

        Define if Pods related to this Workload has the label Version  # noqa: E501

        :return: The version_label of this Workload.  # noqa: E501
        :rtype: bool
        """
        return self._version_label

    @version_label.setter
    def version_label(self, version_label):
        """Sets the version_label of this Workload.

        Define if Pods related to this Workload has the label Version  # noqa: E501

        :param version_label: The version_label of this Workload.  # noqa: E501
        :type: bool
        """
        if version_label is None:
            raise ValueError("Invalid value for `version_label`, must not be `None`")  # noqa: E501

        self._version_label = version_label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Workload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Workload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.attribute_manifests import AttributeManifests  # noqa: F401,E501
from kps_api.models.authorization_policies import AuthorizationPolicies  # noqa: F401,E501
from kps_api.models.cluster_rbac_configs import ClusterRbacConfigs  # noqa: F401,E501
from kps_api.models.destination_rules import DestinationRules  # noqa: F401,E501
from kps_api.models.envoy_filters import EnvoyFilters  # noqa: F401,E501
from kps_api.models.gateways import Gateways  # noqa: F401,E501
from kps_api.models.http_api_spec_bindings import HttpApiSpecBindings  # noqa: F401,E501
from kps_api.models.http_api_specs import HttpApiSpecs  # noqa: F401,E501
from kps_api.models.istio_adapters import IstioAdapters  # noqa: F401,E501
from kps_api.models.istio_handlers import IstioHandlers  # noqa: F401,E501
from kps_api.models.istio_instances import IstioInstances  # noqa: F401,E501
from kps_api.models.istio_rules import IstioRules  # noqa: F401,E501
from kps_api.models.istio_templates import IstioTemplates  # noqa: F401,E501
from kps_api.models.istio_validations import IstioValidations  # noqa: F401,E501
from kps_api.models.mesh_policies import MeshPolicies  # noqa: F401,E501
from kps_api.models.namespace import Namespace  # noqa: F401,E501
from kps_api.models.peer_authentications import PeerAuthentications  # noqa: F401,E501
from kps_api.models.policies import Policies  # noqa: F401,E501
from kps_api.models.quota_spec_bindings import QuotaSpecBindings  # noqa: F401,E501
from kps_api.models.quota_specs import QuotaSpecs  # noqa: F401,E501
from kps_api.models.rbac_configs import RbacConfigs  # noqa: F401,E501
from kps_api.models.request_authentications import RequestAuthentications  # noqa: F401,E501
from kps_api.models.service_entries import ServiceEntries  # noqa: F401,E501
from kps_api.models.service_mesh_policies import ServiceMeshPolicies  # noqa: F401,E501
from kps_api.models.service_mesh_rbac_configs import ServiceMeshRbacConfigs  # noqa: F401,E501
from kps_api.models.service_role_bindings import ServiceRoleBindings  # noqa: F401,E501
from kps_api.models.service_roles import ServiceRoles  # noqa: F401,E501
from kps_api.models.sidecars import Sidecars  # noqa: F401,E501
from kps_api.models.virtual_services import VirtualServices  # noqa: F401,E501
from kps_api.models.workload_entries import WorkloadEntries  # noqa: F401,E501


class IstioConfigList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'adapters': 'IstioAdapters',
        'attribute_manifests': 'AttributeManifests',
        'authorization_policies': 'AuthorizationPolicies',
        'cluster_rbac_configs': 'ClusterRbacConfigs',
        'destination_rules': 'DestinationRules',
        'envoy_filters': 'EnvoyFilters',
        'gateways': 'Gateways',
        'handlers': 'IstioHandlers',
        'http_api_spec_bindings': 'HttpApiSpecBindings',
        'http_api_specs': 'HttpApiSpecs',
        'instances': 'IstioInstances',
        'istio_validations': 'IstioValidations',
        'mesh_policies': 'MeshPolicies',
        'namespace': 'Namespace',
        'peer_authentications': 'PeerAuthentications',
        'policies': 'Policies',
        'quota_spec_bindings': 'QuotaSpecBindings',
        'quota_specs': 'QuotaSpecs',
        'rbac_configs': 'RbacConfigs',
        'request_authentications': 'RequestAuthentications',
        'rules': 'IstioRules',
        'service_entries': 'ServiceEntries',
        'service_mesh_policies': 'ServiceMeshPolicies',
        'service_mesh_rbac_configs': 'ServiceMeshRbacConfigs',
        'service_role_bindings': 'ServiceRoleBindings',
        'service_roles': 'ServiceRoles',
        'sidecars': 'Sidecars',
        'templates': 'IstioTemplates',
        'virtual_services': 'VirtualServices',
        'workload_entries': 'WorkloadEntries'
    }

    attribute_map = {
        'adapters': 'adapters',
        'attribute_manifests': 'attributeManifests',
        'authorization_policies': 'authorizationPolicies',
        'cluster_rbac_configs': 'clusterRbacConfigs',
        'destination_rules': 'destinationRules',
        'envoy_filters': 'envoyFilters',
        'gateways': 'gateways',
        'handlers': 'handlers',
        'http_api_spec_bindings': 'httpApiSpecBindings',
        'http_api_specs': 'httpApiSpecs',
        'instances': 'instances',
        'istio_validations': 'istioValidations',
        'mesh_policies': 'meshPolicies',
        'namespace': 'namespace',
        'peer_authentications': 'peerAuthentications',
        'policies': 'policies',
        'quota_spec_bindings': 'quotaSpecBindings',
        'quota_specs': 'quotaSpecs',
        'rbac_configs': 'rbacConfigs',
        'request_authentications': 'requestAuthentications',
        'rules': 'rules',
        'service_entries': 'serviceEntries',
        'service_mesh_policies': 'serviceMeshPolicies',
        'service_mesh_rbac_configs': 'serviceMeshRbacConfigs',
        'service_role_bindings': 'serviceRoleBindings',
        'service_roles': 'serviceRoles',
        'sidecars': 'sidecars',
        'templates': 'templates',
        'virtual_services': 'virtualServices',
        'workload_entries': 'workloadEntries'
    }

    def __init__(self, adapters=None, attribute_manifests=None, authorization_policies=None, cluster_rbac_configs=None, destination_rules=None, envoy_filters=None, gateways=None, handlers=None, http_api_spec_bindings=None, http_api_specs=None, instances=None, istio_validations=None, mesh_policies=None, namespace=None, peer_authentications=None, policies=None, quota_spec_bindings=None, quota_specs=None, rbac_configs=None, request_authentications=None, rules=None, service_entries=None, service_mesh_policies=None, service_mesh_rbac_configs=None, service_role_bindings=None, service_roles=None, sidecars=None, templates=None, virtual_services=None, workload_entries=None):  # noqa: E501
        """IstioConfigList - a model defined in Swagger"""  # noqa: E501
        self._adapters = None
        self._attribute_manifests = None
        self._authorization_policies = None
        self._cluster_rbac_configs = None
        self._destination_rules = None
        self._envoy_filters = None
        self._gateways = None
        self._handlers = None
        self._http_api_spec_bindings = None
        self._http_api_specs = None
        self._instances = None
        self._istio_validations = None
        self._mesh_policies = None
        self._namespace = None
        self._peer_authentications = None
        self._policies = None
        self._quota_spec_bindings = None
        self._quota_specs = None
        self._rbac_configs = None
        self._request_authentications = None
        self._rules = None
        self._service_entries = None
        self._service_mesh_policies = None
        self._service_mesh_rbac_configs = None
        self._service_role_bindings = None
        self._service_roles = None
        self._sidecars = None
        self._templates = None
        self._virtual_services = None
        self._workload_entries = None
        self.discriminator = None
        if adapters is not None:
            self.adapters = adapters
        if attribute_manifests is not None:
            self.attribute_manifests = attribute_manifests
        if authorization_policies is not None:
            self.authorization_policies = authorization_policies
        if cluster_rbac_configs is not None:
            self.cluster_rbac_configs = cluster_rbac_configs
        if destination_rules is not None:
            self.destination_rules = destination_rules
        if envoy_filters is not None:
            self.envoy_filters = envoy_filters
        if gateways is not None:
            self.gateways = gateways
        if handlers is not None:
            self.handlers = handlers
        if http_api_spec_bindings is not None:
            self.http_api_spec_bindings = http_api_spec_bindings
        if http_api_specs is not None:
            self.http_api_specs = http_api_specs
        if instances is not None:
            self.instances = instances
        if istio_validations is not None:
            self.istio_validations = istio_validations
        if mesh_policies is not None:
            self.mesh_policies = mesh_policies
        self.namespace = namespace
        if peer_authentications is not None:
            self.peer_authentications = peer_authentications
        if policies is not None:
            self.policies = policies
        if quota_spec_bindings is not None:
            self.quota_spec_bindings = quota_spec_bindings
        if quota_specs is not None:
            self.quota_specs = quota_specs
        if rbac_configs is not None:
            self.rbac_configs = rbac_configs
        if request_authentications is not None:
            self.request_authentications = request_authentications
        if rules is not None:
            self.rules = rules
        if service_entries is not None:
            self.service_entries = service_entries
        if service_mesh_policies is not None:
            self.service_mesh_policies = service_mesh_policies
        if service_mesh_rbac_configs is not None:
            self.service_mesh_rbac_configs = service_mesh_rbac_configs
        if service_role_bindings is not None:
            self.service_role_bindings = service_role_bindings
        if service_roles is not None:
            self.service_roles = service_roles
        if sidecars is not None:
            self.sidecars = sidecars
        if templates is not None:
            self.templates = templates
        if virtual_services is not None:
            self.virtual_services = virtual_services
        if workload_entries is not None:
            self.workload_entries = workload_entries

    @property
    def adapters(self):
        """Gets the adapters of this IstioConfigList.  # noqa: E501


        :return: The adapters of this IstioConfigList.  # noqa: E501
        :rtype: IstioAdapters
        """
        return self._adapters

    @adapters.setter
    def adapters(self, adapters):
        """Sets the adapters of this IstioConfigList.


        :param adapters: The adapters of this IstioConfigList.  # noqa: E501
        :type: IstioAdapters
        """

        self._adapters = adapters

    @property
    def attribute_manifests(self):
        """Gets the attribute_manifests of this IstioConfigList.  # noqa: E501


        :return: The attribute_manifests of this IstioConfigList.  # noqa: E501
        :rtype: AttributeManifests
        """
        return self._attribute_manifests

    @attribute_manifests.setter
    def attribute_manifests(self, attribute_manifests):
        """Sets the attribute_manifests of this IstioConfigList.


        :param attribute_manifests: The attribute_manifests of this IstioConfigList.  # noqa: E501
        :type: AttributeManifests
        """

        self._attribute_manifests = attribute_manifests

    @property
    def authorization_policies(self):
        """Gets the authorization_policies of this IstioConfigList.  # noqa: E501


        :return: The authorization_policies of this IstioConfigList.  # noqa: E501
        :rtype: AuthorizationPolicies
        """
        return self._authorization_policies

    @authorization_policies.setter
    def authorization_policies(self, authorization_policies):
        """Sets the authorization_policies of this IstioConfigList.


        :param authorization_policies: The authorization_policies of this IstioConfigList.  # noqa: E501
        :type: AuthorizationPolicies
        """

        self._authorization_policies = authorization_policies

    @property
    def cluster_rbac_configs(self):
        """Gets the cluster_rbac_configs of this IstioConfigList.  # noqa: E501


        :return: The cluster_rbac_configs of this IstioConfigList.  # noqa: E501
        :rtype: ClusterRbacConfigs
        """
        return self._cluster_rbac_configs

    @cluster_rbac_configs.setter
    def cluster_rbac_configs(self, cluster_rbac_configs):
        """Sets the cluster_rbac_configs of this IstioConfigList.


        :param cluster_rbac_configs: The cluster_rbac_configs of this IstioConfigList.  # noqa: E501
        :type: ClusterRbacConfigs
        """

        self._cluster_rbac_configs = cluster_rbac_configs

    @property
    def destination_rules(self):
        """Gets the destination_rules of this IstioConfigList.  # noqa: E501


        :return: The destination_rules of this IstioConfigList.  # noqa: E501
        :rtype: DestinationRules
        """
        return self._destination_rules

    @destination_rules.setter
    def destination_rules(self, destination_rules):
        """Sets the destination_rules of this IstioConfigList.


        :param destination_rules: The destination_rules of this IstioConfigList.  # noqa: E501
        :type: DestinationRules
        """

        self._destination_rules = destination_rules

    @property
    def envoy_filters(self):
        """Gets the envoy_filters of this IstioConfigList.  # noqa: E501


        :return: The envoy_filters of this IstioConfigList.  # noqa: E501
        :rtype: EnvoyFilters
        """
        return self._envoy_filters

    @envoy_filters.setter
    def envoy_filters(self, envoy_filters):
        """Sets the envoy_filters of this IstioConfigList.


        :param envoy_filters: The envoy_filters of this IstioConfigList.  # noqa: E501
        :type: EnvoyFilters
        """

        self._envoy_filters = envoy_filters

    @property
    def gateways(self):
        """Gets the gateways of this IstioConfigList.  # noqa: E501


        :return: The gateways of this IstioConfigList.  # noqa: E501
        :rtype: Gateways
        """
        return self._gateways

    @gateways.setter
    def gateways(self, gateways):
        """Sets the gateways of this IstioConfigList.


        :param gateways: The gateways of this IstioConfigList.  # noqa: E501
        :type: Gateways
        """

        self._gateways = gateways

    @property
    def handlers(self):
        """Gets the handlers of this IstioConfigList.  # noqa: E501


        :return: The handlers of this IstioConfigList.  # noqa: E501
        :rtype: IstioHandlers
        """
        return self._handlers

    @handlers.setter
    def handlers(self, handlers):
        """Sets the handlers of this IstioConfigList.


        :param handlers: The handlers of this IstioConfigList.  # noqa: E501
        :type: IstioHandlers
        """

        self._handlers = handlers

    @property
    def http_api_spec_bindings(self):
        """Gets the http_api_spec_bindings of this IstioConfigList.  # noqa: E501


        :return: The http_api_spec_bindings of this IstioConfigList.  # noqa: E501
        :rtype: HttpApiSpecBindings
        """
        return self._http_api_spec_bindings

    @http_api_spec_bindings.setter
    def http_api_spec_bindings(self, http_api_spec_bindings):
        """Sets the http_api_spec_bindings of this IstioConfigList.


        :param http_api_spec_bindings: The http_api_spec_bindings of this IstioConfigList.  # noqa: E501
        :type: HttpApiSpecBindings
        """

        self._http_api_spec_bindings = http_api_spec_bindings

    @property
    def http_api_specs(self):
        """Gets the http_api_specs of this IstioConfigList.  # noqa: E501


        :return: The http_api_specs of this IstioConfigList.  # noqa: E501
        :rtype: HttpApiSpecs
        """
        return self._http_api_specs

    @http_api_specs.setter
    def http_api_specs(self, http_api_specs):
        """Sets the http_api_specs of this IstioConfigList.


        :param http_api_specs: The http_api_specs of this IstioConfigList.  # noqa: E501
        :type: HttpApiSpecs
        """

        self._http_api_specs = http_api_specs

    @property
    def instances(self):
        """Gets the instances of this IstioConfigList.  # noqa: E501


        :return: The instances of this IstioConfigList.  # noqa: E501
        :rtype: IstioInstances
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """Sets the instances of this IstioConfigList.


        :param instances: The instances of this IstioConfigList.  # noqa: E501
        :type: IstioInstances
        """

        self._instances = instances

    @property
    def istio_validations(self):
        """Gets the istio_validations of this IstioConfigList.  # noqa: E501


        :return: The istio_validations of this IstioConfigList.  # noqa: E501
        :rtype: IstioValidations
        """
        return self._istio_validations

    @istio_validations.setter
    def istio_validations(self, istio_validations):
        """Sets the istio_validations of this IstioConfigList.


        :param istio_validations: The istio_validations of this IstioConfigList.  # noqa: E501
        :type: IstioValidations
        """

        self._istio_validations = istio_validations

    @property
    def mesh_policies(self):
        """Gets the mesh_policies of this IstioConfigList.  # noqa: E501


        :return: The mesh_policies of this IstioConfigList.  # noqa: E501
        :rtype: MeshPolicies
        """
        return self._mesh_policies

    @mesh_policies.setter
    def mesh_policies(self, mesh_policies):
        """Sets the mesh_policies of this IstioConfigList.


        :param mesh_policies: The mesh_policies of this IstioConfigList.  # noqa: E501
        :type: MeshPolicies
        """

        self._mesh_policies = mesh_policies

    @property
    def namespace(self):
        """Gets the namespace of this IstioConfigList.  # noqa: E501


        :return: The namespace of this IstioConfigList.  # noqa: E501
        :rtype: Namespace
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this IstioConfigList.


        :param namespace: The namespace of this IstioConfigList.  # noqa: E501
        :type: Namespace
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def peer_authentications(self):
        """Gets the peer_authentications of this IstioConfigList.  # noqa: E501


        :return: The peer_authentications of this IstioConfigList.  # noqa: E501
        :rtype: PeerAuthentications
        """
        return self._peer_authentications

    @peer_authentications.setter
    def peer_authentications(self, peer_authentications):
        """Sets the peer_authentications of this IstioConfigList.


        :param peer_authentications: The peer_authentications of this IstioConfigList.  # noqa: E501
        :type: PeerAuthentications
        """

        self._peer_authentications = peer_authentications

    @property
    def policies(self):
        """Gets the policies of this IstioConfigList.  # noqa: E501


        :return: The policies of this IstioConfigList.  # noqa: E501
        :rtype: Policies
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """Sets the policies of this IstioConfigList.


        :param policies: The policies of this IstioConfigList.  # noqa: E501
        :type: Policies
        """

        self._policies = policies

    @property
    def quota_spec_bindings(self):
        """Gets the quota_spec_bindings of this IstioConfigList.  # noqa: E501


        :return: The quota_spec_bindings of this IstioConfigList.  # noqa: E501
        :rtype: QuotaSpecBindings
        """
        return self._quota_spec_bindings

    @quota_spec_bindings.setter
    def quota_spec_bindings(self, quota_spec_bindings):
        """Sets the quota_spec_bindings of this IstioConfigList.


        :param quota_spec_bindings: The quota_spec_bindings of this IstioConfigList.  # noqa: E501
        :type: QuotaSpecBindings
        """

        self._quota_spec_bindings = quota_spec_bindings

    @property
    def quota_specs(self):
        """Gets the quota_specs of this IstioConfigList.  # noqa: E501


        :return: The quota_specs of this IstioConfigList.  # noqa: E501
        :rtype: QuotaSpecs
        """
        return self._quota_specs

    @quota_specs.setter
    def quota_specs(self, quota_specs):
        """Sets the quota_specs of this IstioConfigList.


        :param quota_specs: The quota_specs of this IstioConfigList.  # noqa: E501
        :type: QuotaSpecs
        """

        self._quota_specs = quota_specs

    @property
    def rbac_configs(self):
        """Gets the rbac_configs of this IstioConfigList.  # noqa: E501


        :return: The rbac_configs of this IstioConfigList.  # noqa: E501
        :rtype: RbacConfigs
        """
        return self._rbac_configs

    @rbac_configs.setter
    def rbac_configs(self, rbac_configs):
        """Sets the rbac_configs of this IstioConfigList.


        :param rbac_configs: The rbac_configs of this IstioConfigList.  # noqa: E501
        :type: RbacConfigs
        """

        self._rbac_configs = rbac_configs

    @property
    def request_authentications(self):
        """Gets the request_authentications of this IstioConfigList.  # noqa: E501


        :return: The request_authentications of this IstioConfigList.  # noqa: E501
        :rtype: RequestAuthentications
        """
        return self._request_authentications

    @request_authentications.setter
    def request_authentications(self, request_authentications):
        """Sets the request_authentications of this IstioConfigList.


        :param request_authentications: The request_authentications of this IstioConfigList.  # noqa: E501
        :type: RequestAuthentications
        """

        self._request_authentications = request_authentications

    @property
    def rules(self):
        """Gets the rules of this IstioConfigList.  # noqa: E501


        :return: The rules of this IstioConfigList.  # noqa: E501
        :rtype: IstioRules
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this IstioConfigList.


        :param rules: The rules of this IstioConfigList.  # noqa: E501
        :type: IstioRules
        """

        self._rules = rules

    @property
    def service_entries(self):
        """Gets the service_entries of this IstioConfigList.  # noqa: E501


        :return: The service_entries of this IstioConfigList.  # noqa: E501
        :rtype: ServiceEntries
        """
        return self._service_entries

    @service_entries.setter
    def service_entries(self, service_entries):
        """Sets the service_entries of this IstioConfigList.


        :param service_entries: The service_entries of this IstioConfigList.  # noqa: E501
        :type: ServiceEntries
        """

        self._service_entries = service_entries

    @property
    def service_mesh_policies(self):
        """Gets the service_mesh_policies of this IstioConfigList.  # noqa: E501


        :return: The service_mesh_policies of this IstioConfigList.  # noqa: E501
        :rtype: ServiceMeshPolicies
        """
        return self._service_mesh_policies

    @service_mesh_policies.setter
    def service_mesh_policies(self, service_mesh_policies):
        """Sets the service_mesh_policies of this IstioConfigList.


        :param service_mesh_policies: The service_mesh_policies of this IstioConfigList.  # noqa: E501
        :type: ServiceMeshPolicies
        """

        self._service_mesh_policies = service_mesh_policies

    @property
    def service_mesh_rbac_configs(self):
        """Gets the service_mesh_rbac_configs of this IstioConfigList.  # noqa: E501


        :return: The service_mesh_rbac_configs of this IstioConfigList.  # noqa: E501
        :rtype: ServiceMeshRbacConfigs
        """
        return self._service_mesh_rbac_configs

    @service_mesh_rbac_configs.setter
    def service_mesh_rbac_configs(self, service_mesh_rbac_configs):
        """Sets the service_mesh_rbac_configs of this IstioConfigList.


        :param service_mesh_rbac_configs: The service_mesh_rbac_configs of this IstioConfigList.  # noqa: E501
        :type: ServiceMeshRbacConfigs
        """

        self._service_mesh_rbac_configs = service_mesh_rbac_configs

    @property
    def service_role_bindings(self):
        """Gets the service_role_bindings of this IstioConfigList.  # noqa: E501


        :return: The service_role_bindings of this IstioConfigList.  # noqa: E501
        :rtype: ServiceRoleBindings
        """
        return self._service_role_bindings

    @service_role_bindings.setter
    def service_role_bindings(self, service_role_bindings):
        """Sets the service_role_bindings of this IstioConfigList.


        :param service_role_bindings: The service_role_bindings of this IstioConfigList.  # noqa: E501
        :type: ServiceRoleBindings
        """

        self._service_role_bindings = service_role_bindings

    @property
    def service_roles(self):
        """Gets the service_roles of this IstioConfigList.  # noqa: E501


        :return: The service_roles of this IstioConfigList.  # noqa: E501
        :rtype: ServiceRoles
        """
        return self._service_roles

    @service_roles.setter
    def service_roles(self, service_roles):
        """Sets the service_roles of this IstioConfigList.


        :param service_roles: The service_roles of this IstioConfigList.  # noqa: E501
        :type: ServiceRoles
        """

        self._service_roles = service_roles

    @property
    def sidecars(self):
        """Gets the sidecars of this IstioConfigList.  # noqa: E501


        :return: The sidecars of this IstioConfigList.  # noqa: E501
        :rtype: Sidecars
        """
        return self._sidecars

    @sidecars.setter
    def sidecars(self, sidecars):
        """Sets the sidecars of this IstioConfigList.


        :param sidecars: The sidecars of this IstioConfigList.  # noqa: E501
        :type: Sidecars
        """

        self._sidecars = sidecars

    @property
    def templates(self):
        """Gets the templates of this IstioConfigList.  # noqa: E501


        :return: The templates of this IstioConfigList.  # noqa: E501
        :rtype: IstioTemplates
        """
        return self._templates

    @templates.setter
    def templates(self, templates):
        """Sets the templates of this IstioConfigList.


        :param templates: The templates of this IstioConfigList.  # noqa: E501
        :type: IstioTemplates
        """

        self._templates = templates

    @property
    def virtual_services(self):
        """Gets the virtual_services of this IstioConfigList.  # noqa: E501


        :return: The virtual_services of this IstioConfigList.  # noqa: E501
        :rtype: VirtualServices
        """
        return self._virtual_services

    @virtual_services.setter
    def virtual_services(self, virtual_services):
        """Sets the virtual_services of this IstioConfigList.


        :param virtual_services: The virtual_services of this IstioConfigList.  # noqa: E501
        :type: VirtualServices
        """

        self._virtual_services = virtual_services

    @property
    def workload_entries(self):
        """Gets the workload_entries of this IstioConfigList.  # noqa: E501


        :return: The workload_entries of this IstioConfigList.  # noqa: E501
        :rtype: WorkloadEntries
        """
        return self._workload_entries

    @workload_entries.setter
    def workload_entries(self, workload_entries):
        """Sets the workload_entries of this IstioConfigList.


        :param workload_entries: The workload_entries of this IstioConfigList.  # noqa: E501
        :type: WorkloadEntries
        """

        self._workload_entries = workload_entries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IstioConfigList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IstioConfigList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RuntimeEnvironment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'docker_profile_id': 'str',
        'docker_repo_uri': 'str',
        'dockerfile': 'str',
        'id': 'str',
        'language': 'str',
        'name': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'description': 'description',
        'docker_profile_id': 'dockerProfileID',
        'docker_repo_uri': 'dockerRepoURI',
        'dockerfile': 'dockerfile',
        'id': 'id',
        'language': 'language',
        'name': 'name',
        'project_id': 'projectId'
    }

    def __init__(self, description=None, docker_profile_id=None, docker_repo_uri=None, dockerfile=None, id=None, language=None, name=None, project_id=None):  # noqa: E501
        """RuntimeEnvironment - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._docker_profile_id = None
        self._docker_repo_uri = None
        self._dockerfile = None
        self._id = None
        self._language = None
        self._name = None
        self._project_id = None
        self.discriminator = None
        if description is not None:
            self.description = description
        if docker_profile_id is not None:
            self.docker_profile_id = docker_profile_id
        if docker_repo_uri is not None:
            self.docker_repo_uri = docker_repo_uri
        if dockerfile is not None:
            self.dockerfile = dockerfile
        if id is not None:
            self.id = id
        self.language = language
        self.name = name
        if project_id is not None:
            self.project_id = project_id

    @property
    def description(self):
        """Gets the description of this RuntimeEnvironment.  # noqa: E501

        Runtime description.  # noqa: E501

        :return: The description of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RuntimeEnvironment.

        Runtime description.  # noqa: E501

        :param description: The description of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def docker_profile_id(self):
        """Gets the docker_profile_id of this RuntimeEnvironment.  # noqa: E501

        DockerProfile ID (Container registry profile) used by this script runtime.  # noqa: E501

        :return: The docker_profile_id of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._docker_profile_id

    @docker_profile_id.setter
    def docker_profile_id(self, docker_profile_id):
        """Sets the docker_profile_id of this RuntimeEnvironment.

        DockerProfile ID (Container registry profile) used by this script runtime.  # noqa: E501

        :param docker_profile_id: The docker_profile_id of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._docker_profile_id = docker_profile_id

    @property
    def docker_repo_uri(self):
        """Gets the docker_repo_uri of this RuntimeEnvironment.  # noqa: E501

        Docker repository URI of the script runtime.  # noqa: E501

        :return: The docker_repo_uri of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._docker_repo_uri

    @docker_repo_uri.setter
    def docker_repo_uri(self, docker_repo_uri):
        """Sets the docker_repo_uri of this RuntimeEnvironment.

        Docker repository URI of the script runtime.  # noqa: E501

        :param docker_repo_uri: The docker_repo_uri of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._docker_repo_uri = docker_repo_uri

    @property
    def dockerfile(self):
        """Gets the dockerfile of this RuntimeEnvironment.  # noqa: E501

        Dockerfile for the script runtime. Serves as documentation for the script runtime.  # noqa: E501

        :return: The dockerfile of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._dockerfile

    @dockerfile.setter
    def dockerfile(self, dockerfile):
        """Sets the dockerfile of this RuntimeEnvironment.

        Dockerfile for the script runtime. Serves as documentation for the script runtime.  # noqa: E501

        :param dockerfile: The dockerfile of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._dockerfile = dockerfile

    @property
    def id(self):
        """Gets the id of this RuntimeEnvironment.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RuntimeEnvironment.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def language(self):
        """Gets the language of this RuntimeEnvironment.  # noqa: E501

        Runtime enviroment script language.  # noqa: E501

        :return: The language of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this RuntimeEnvironment.

        Runtime enviroment script language.  # noqa: E501

        :param language: The language of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def name(self):
        """Gets the name of this RuntimeEnvironment.  # noqa: E501

        Name of the runtime environment.  # noqa: E501

        :return: The name of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RuntimeEnvironment.

        Name of the runtime environment.  # noqa: E501

        :param name: The name of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this RuntimeEnvironment.  # noqa: E501

        ID of parent project, required for custom (non-built-in) script runtimes.  # noqa: E501

        :return: The project_id of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this RuntimeEnvironment.

        ID of parent project, required for custom (non-built-in) script runtimes.  # noqa: E501

        :param project_id: The project_id of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuntimeEnvironment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuntimeEnvironment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
